commit
stringlengths
40
40
subject
stringlengths
4
1.73k
repos
stringlengths
5
127k
old_file
stringlengths
2
751
new_file
stringlengths
2
751
new_contents
stringlengths
1
8.98k
old_contents
stringlengths
0
6.59k
license
stringclasses
13 values
lang
stringclasses
23 values
13cbcc63875f344c81299c8b136c4ff7b53eeab1
Add eyetrack_wordpos.r
ShanKothari/EyeTrack
eyetrack_wordpos.r
eyetrack_wordpos.r
##word_dims is an array with words in row 1, pixel lengths in row 2, heights ##(if needed) in row 3 line_number<-function(word_dims,space_length,margin){ lines=1 tot_length=0 word_lines<-array(dim=c(dim(word_dims)[[1]],4)) word_lines[,1:3]<-word_dims for(i in 1:dim(word_dims)[[1]]){ ##"\r" denotes a return in the...
mit
R
4458eac9047c6f7e377a2cb4e60526e6b0035855
Add missing ib161 file
ryanlovett/datahub,berkeley-dsep-infra/datahub,ryanlovett/datahub,berkeley-dsep-infra/datahub,berkeley-dsep-infra/datahub,ryanlovett/datahub
deployments/datahub/images/default/r-packages/ib161.r
deployments/datahub/images/default/r-packages/ib161.r
#!/usr/bin/env Rscript source("/tmp/class-libs.R") class_name = "IB161" class_libs = c( "pegas", "0.14" ) class_libs_install_version(class_name, class_libs)
bsd-3-clause
R
cae8b6d9ad11b00e359dd53ad1f216ca6a7d93fd
Add (R) script to generate histograms of projects wto. number of commits
qhanam/Pangor,saltlab/Pangor,saltlab/Pangor,qhanam/Pangor,qhanam/Pangor,qhanam/Pangor,saltlab/Pangor,saltlab/Pangor,qhanam/Pangor,saltlab/Pangor
tools/histogram_from_repository_metrics.r
tools/histogram_from_repository_metrics.r
setwd("/home/brito/salt/JSRepairClass/input/applications/") data <- read.csv("repositories_metrics.csv") hist(data$TotalCommits, main = paste("Histogram for ", nrow(data), "node.js applications"), xlab = "Total number of commits") setwd("/home/brito/salt/JSRepairClass/input/modules/") data <- read.csv("repositories_me...
apache-2.0
R
ecdeaad9289109d4ccc1a164b6a7f29248ecb3d2
Remove the extra endif by merge error
reyoung/Paddle,chengduoZH/Paddle,yu239/Paddle,alvations/Paddle,Canpio/Paddle,hedaoyuan/Paddle,zhouxiao-coder/Paddle,reyoung/Paddle,Canpio/Paddle,jacquesqiao/Paddle,dayhaha/Paddle,luotao1/Paddle,gangliao/Paddle,beckett1124/Paddle,zhouxiao-coder/Paddle,Canpio/Paddle,yu239/Paddle,wen-bo-yang/Paddle,lispc/Paddle,luotao1/Pa...
paddle/cuda/include/hl_device_functions.cuh
paddle/cuda/include/hl_device_functions.cuh
/* Copyright (c) 2016 Baidu, Inc. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to ...
/* Copyright (c) 2016 Baidu, Inc. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to ...
apache-2.0
Cuda
3c08c87620094956f22d75c6b2333504e54526a7
Test min_element with thrust::device in __device__ code.
sdalton1/thrust,Ricardo666666/thrust,thrust/thrust,egaburov/thrust,arnabgho/thrust,thrust/thrust,jaredhoberock/thrust,thrust/thrust,xiongzhanblake/thrust,Ricardo666666/thrust,Ricardo666666/thrust,raygit/thrust,sarvex/thrust,dachziegel/thrust,andrewcorrigan/thrust-multi-permutation-iterator,zhenglaizhang/thrust,egaburov...
testing/backend/cuda/min_element.cu
testing/backend/cuda/min_element.cu
#include <unittest/unittest.h> #include <thrust/extrema.h> #include <thrust/execution_policy.h> template<typename ExecutionPolicy, typename Iterator, typename Iterator2> __global__ void min_element_kernel(ExecutionPolicy exec, Iterator first, Iterator last, Iterator2 result) { *result = thrust::min_element(exec, fi...
#include <unittest/unittest.h> #include <thrust/extrema.h> #include <thrust/execution_policy.h> template<typename Iterator, typename Iterator2> __global__ void min_element_kernel(Iterator first, Iterator last, Iterator2 result) { *result = thrust::min_element(thrust::seq, first, last); } template<typename Iterato...
apache-2.0
Cuda
9aaa29d1ce6f4db2f4daf47eabbb44dd4a75fcdb
fix CreateOp to accept dtypes of uint8 and int32 (#9561)
zhreshold/mxnet,apache/incubator-mxnet,zhreshold/mxnet,zhreshold/mxnet,navrasio/mxnet,dmlc/mxnet,luoyetx/mxnet,jiajiechen/mxnet,fullfanta/mxnet,navrasio/mxnet,TuSimple/mxnet,sxjscience/mxnet,reminisce/mxnet,jiajiechen/mxnet,leezu/mxnet,precedenceguo/mxnet,rahul003/mxnet,leezu/mxnet,navrasio/mxnet,larroy/mxnet,ptrendx/m...
src/operator/slice_channel.cu
src/operator/slice_channel.cu
/* * Licensed to the Apache Software Foundation (ASF) under one * or more contributor license agreements. See the NOTICE file * distributed with this work for additional information * regarding copyright ownership. The ASF licenses this file * to you under the Apache License, Version 2.0 (the * "License"); you ...
/* * Licensed to the Apache Software Foundation (ASF) under one * or more contributor license agreements. See the NOTICE file * distributed with this work for additional information * regarding copyright ownership. The ASF licenses this file * to you under the Apache License, Version 2.0 (the * "License"); you ...
apache-2.0
Cuda
8cd91b3df0035899b6cb33a96ab44c1a19d1c2cc
Update cuda snippet illustrating Cuda function pointers
ForestClaw/forestclaw,ForestClaw/forestclaw,ForestClaw/forestclaw,ForestClaw/forestclaw,ForestClaw/forestclaw,ForestClaw/forestclaw
snippets/tst_cuda_function_ptrs/tst_fptrs.cu
snippets/tst_cuda_function_ptrs/tst_fptrs.cu
#include "tst_fptrs.h" #include "user_f.h" #include <stdio.h> __global__ void kernel(fc2d_cuda_t f,float x, float *y) { *y = f(x); return; } int main() { float x; float y, *y_dev; fc2d_assign_cuda_ptr_t f_assign_user; fc2d_cuda_t h_f; /* User definitions */ x = 5; f_assign_user ...
#include "tst_fptrs.h" #include "user_f.h" #include <stdio.h> void assign_cuda_ptr(fc2d_cuda_t* h_f, fc2d_cuda_t f) { cudaError_t ce = cudaMemcpyFromSymbol(h_f, f, sizeof(fc2d_cuda_t)); if(ce != cudaSuccess) { printf("ERROR: %s\n",cudaGetErrorString(ce)); exit(0); } else { ...
bsd-2-clause
Cuda
c6186120c32c98fb91609a1bffdc98c7df4f0aae
fix softmax_op code line > 80
jacquesqiao/Paddle,pengli09/Paddle,pengli09/Paddle,lispc/Paddle,pkuyym/Paddle,tensor-tang/Paddle,PaddlePaddle/Paddle,pengli09/Paddle,luotao1/Paddle,hedaoyuan/Paddle,lispc/Paddle,hedaoyuan/Paddle,pengli09/Paddle,QiJune/Paddle,reyoung/Paddle,luotao1/Paddle,putcn/Paddle,Canpio/Paddle,chengduoZH/Paddle,Canpio/Paddle,tensor...
paddle/operators/softmax_op.cu
paddle/operators/softmax_op.cu
/* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applica...
/* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applica...
apache-2.0
Cuda
88cb3504ff9bcd8435ef683d3ceab817b9df7bf3
Update allocators.cu test
GPUOpen-ProfessionalCompute-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP,ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,ROCm-Developer-Tools/HIP,GPUOpen-ProfessionalCompute-Tools/HIP
tests/hipify-clang/unit_tests/samples/allocators.cu
tests/hipify-clang/unit_tests/samples/allocators.cu
// RUN: %run_test hipify "%s" "%t" %hipify_args %clang_args #pragma once // CHECK: #include <hip/hip_runtime.h> #include <cuda_runtime.h> #include <math.h> /** * Allocate GPU memory for `count` elements of type `T`. */ template<typename T> static T* gpuMalloc(size_t count) { T* ret = nullptr; // CHECK: hipM...
// RUN: %run_test hipify "%s" "%t" %hipify_args %clang_args #pragma once #include <cuda_runtime.h> /** * Allocate GPU memory for `count` elements of type `T`. */ template<typename T> static T* gpuMalloc(size_t count) { T* ret = nullptr; // CHECK: hipMalloc(&ret, count * sizeof(T)); cudaMalloc(&ret, co...
mit
Cuda
f9de6b48e5c3fc14c0a917cd3495d9c247b14c56
Enable LARS on GPU [PR Patch #2115]
Yangqing/caffe2,xzturn/caffe2,xzturn/caffe2,Yangqing/caffe2,caffe2/caffe2,Yangqing/caffe2,xzturn/caffe2,xzturn/caffe2,Yangqing/caffe2,xzturn/caffe2,Yangqing/caffe2
caffe2/sgd/lars_op_gpu.cu
caffe2/sgd/lars_op_gpu.cu
/** * Copyright (c) 2016-present, Facebook, Inc. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable ...
/** * Copyright (c) 2016-present, Facebook, Inc. * * Licensed under the Apache License, Version 2.0 (the "License"); * you may not use this file except in compliance with the License. * You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable ...
apache-2.0
Cuda
9f69b633109a9ef6c0cf63861e980109009fb731
Fix flush-denormals.cu test so that it checks what it intends to CHECK.
llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-cl...
test/CodeGenCUDA/flush-denormals.cu
test/CodeGenCUDA/flush-denormals.cu
// RUN: %clang_cc1 -fcuda-is-device \ // RUN: -triple nvptx-nvidia-cuda -emit-llvm -o - %s | \ // RUN: FileCheck %s -check-prefix CHECK -check-prefix NOFTZ // RUN: %clang_cc1 -fcuda-is-device -fcuda-flush-denormals-to-zero \ // RUN: -triple nvptx-nvidia-cuda -emit-llvm -o - %s | \ // RUN: FileCheck %s -check-pr...
// RUN: %clang_cc1 -fcuda-is-device \ // RUN: -triple nvptx-nvidia-cuda -emit-llvm -o - %s | FileCheck %s -check-prefix NOFTZ // RUN: %clang_cc1 -fcuda-is-device -fcuda-flush-denormals-to-zero \ // RUN: -triple nvptx-nvidia-cuda -emit-llvm -o - %s | FileCheck %s -check-prefix FTZ #include "Inputs/cuda.h" // Check...
apache-2.0
Cuda
05288a698f0be37a63c9682db9f6dacfdb1efd6b
Fix new tuple algorithm tests to compile in C++11 mode.
jaredhoberock/thrust,jaredhoberock/thrust,andrewcorrigan/thrust-multi-permutation-iterator,thrust/thrust,andrewcorrigan/thrust-multi-permutation-iterator,jaredhoberock/thrust,thrust/thrust,thrust/thrust,jaredhoberock/thrust,thrust/thrust,thrust/thrust,jaredhoberock/thrust,andrewcorrigan/thrust-multi-permutation-iterato...
testing/tuple_algorithms.cu
testing/tuple_algorithms.cu
#include <thrust/detail/config.h> #if THRUST_CPP_DIALECT >= 2011 #include <unittest/unittest.h> #include <thrust/detail/tuple_algorithms.h> #include <thrust/type_traits/integer_sequence.h> // FIXME: Replace with C++14 style `thrust::square<>` when we have it. struct custom_square { template <typename T> __host_...
#include <thrust/detail/config.h> #if THRUST_CPP_DIALECT >= 2011 #include <unittest/unittest.h> #include <thrust/detail/tuple_algorithms.h> // FIXME: Replace with C++14 style `thrust::square<>` when we have it. struct custom_square { template <typename T> T operator()(T v) const { return v * v; } }; v...
apache-2.0
Cuda
9ba10fc2720522ab544bf48b060fd2bb5c13171f
Remove redundant forward declaration
RichieSams/rapt,RichieSams/rapt
source/basic_path_tracer/cuda_kernel_call_wrapper.cu
source/basic_path_tracer/cuda_kernel_call_wrapper.cu
/* rapt - RichieSam's Adventures in Path Tracing * * rapt is the legal property of Adrian Astley * Copyright Adrian Astley 2015 */ #include "basic_path_tracer/path_trace.cuh" uint32 WangHash(uint32 a) { a = (a ^ 61) ^ (a >> 16); a = a + (a << 3); a = a ^ (a >> 4); a = a * 0x27d4eb2d; a = a ^ ...
/* rapt - RichieSam's Adventures in Path Tracing * * rapt is the legal property of Adrian Astley * Copyright Adrian Astley 2015 */ #include "basic_path_tracer/path_trace.cuh" namespace Scene { struct Sphere; } uint32 WangHash(uint32 a) { a = (a ^ 61) ^ (a >> 16); a = a + (a << 3); a = a ^ (a >> 4); ...
apache-2.0
Cuda
bf4ba07a547028a243d78a5a6cb08854c9dd9ebe
Update io.cuh
chuckre/DigitalPopulations,chuckre/DigitalPopulations,chuckre/DigitalPopulations,chuckre/DigitalPopulations,chuckre/DigitalPopulations
QuantumPopulationGeoAnalytics/DigPopKernelAnalysis/src/io.cuh
QuantumPopulationGeoAnalytics/DigPopKernelAnalysis/src/io.cuh
/* Contributors: Yizhao Gao (yizhaotsccsj@gmail.com) */ #ifndef IOH #define IOH int getHHNum(FILE * file); bool readPointsP(FILE * hhFile, FILE * popFile, int nHH, int &popCount, int &pNCase, float * xCol, float * yCol, float * pCount, float * cCount, char * mapLogic, char * personColName); bool readPointsH(FILE * ...
#ifndef IOH #define IOH int getHHNum(FILE * file); bool readPointsP(FILE * hhFile, FILE * popFile, int nHH, int &popCount, int &pNCase, float * xCol, float * yCol, float * pCount, float * cCount, char * mapLogic, char * personColName); bool readPointsH(FILE * file, int nHH, int &positiveCount, float * xCol, float * yC...
apache-2.0
Cuda
61bcc76951200d65cfc6ad28b80d27f91c99c12c
Test equal algorithms with thrust::device in __device__ code.
sdalton1/thrust,xiongzhanblake/thrust_src,xiongzhanblake/thrust,zeryx/thrust,Ricardo666666/thrust,dachziegel/thrust,jaredhoberock/thrust,egaburov/thrust,mohamed-ali/thrust,marksantos/thrust,thvasilo/thrust,xiongzhanblake/thrust_src,raygit/thrust,zeryx/thrust,andrewcorrigan/thrust-multi-permutation-iterator,sarvex/thrus...
testing/backend/cuda/equal.cu
testing/backend/cuda/equal.cu
#include <unittest/unittest.h> #include <thrust/equal.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename ExecutionPolicy, typename Iterator1, typename Iterator2, typename Iterator3> __global__ void equal_kernel(ExecutionPolicy exec, Iterator1 first1, Iterator1 last1, Iterator2 fi...
#include <unittest/unittest.h> #include <thrust/equal.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2, typename Iterator3> __global__ void equal_kernel(Iterator1 first1, Iterator1 last1, Iterator2 first2, Iterator3 result) { *result = thrust::eq...
apache-2.0
Cuda
b56a470b2e355a1ad5c4988d03d996fbbb7511bb
Add TestCountingIteratorLowerBound and mark it as KNOWN_FAILURE
google-code-export/thrust,levendlee/thrust,allendaicool/thrust,google-code-export/thrust,Vishwa07/thrust,hemmingway/thrust,rdmenezes/thrust,lishi0927/thrust,allendaicool/thrust,rdmenezes/thrust,lishi0927/thrust,allendaicool/thrust,julianromera/thrust,levendlee/thrust,bfurtaw/thrust,lishi0927/thrust,Vishwa07/thrust,Vish...
testing/counting_iterator.cu
testing/counting_iterator.cu
#include <thrusttest/unittest.h> #include <thrust/iterator/counting_iterator.h> #include <thrust/sort.h> #include <thrust/binary_search.h> void TestCountingIteratorIncrement(void) { thrust::experimental::counting_iterator<int> iter(0); ASSERT_EQUAL(*iter, 0); iter++; ASSERT_EQUAL(*iter, 1); ...
#include <thrusttest/unittest.h> #include <thrust/iterator/counting_iterator.h> void TestCountingIteratorIncrement(void) { thrust::experimental::counting_iterator<int> iter(0); ASSERT_EQUAL(*iter, 0); iter++; ASSERT_EQUAL(*iter, 1); iter++; iter++; ASSERT_EQUAL(*iter, 3); ...
apache-2.0
Cuda
4f4a94c6c76846a21e743982bd7d3785dd59ddfb
Update rasterStat.cuh
chuckre/DigitalPopulations,chuckre/DigitalPopulations,chuckre/DigitalPopulations,chuckre/DigitalPopulations,chuckre/DigitalPopulations
QuantumPopulationGeoAnalytics/DigPopKernelAnalysis/src/rasterStat.cuh
QuantumPopulationGeoAnalytics/DigPopKernelAnalysis/src/rasterStat.cuh
/* Contributors: Yizhao Gao (yizhaotsccsj@gmail.com) */ #ifndef RSH #define RSH int rasterStat(char * inputFileName, int minRzn, int numRzn, char * inputPCName, float xMin, float yMin, float xMax, float yMax, float cellSize, char * outputFileName, int epsgCode); #endif
#ifndef RSH #define RSH int rasterStat(char * inputFileName, int minRzn, int numRzn, char * inputPCName, float xMin, float yMin, float xMax, float yMax, float cellSize, char * outputFileName, int epsgCode); #endif
apache-2.0
Cuda
eac28f7194822f594ce6d605d70d630af948c9f4
Enforce GPU computation
wichtounet/etl-gpu-blas,wichtounet/etl-gpu-blas
src/sum.cu
src/sum.cu
//======================================================================= // Copyright (c) 2017 Baptiste Wicht // Distributed under the terms of the MIT License. // (See accompanying file LICENSE or copy at // http://opensource.org/licenses/MIT) //=======================================================================...
//======================================================================= // Copyright (c) 2017 Baptiste Wicht // Distributed under the terms of the MIT License. // (See accompanying file LICENSE or copy at // http://opensource.org/licenses/MIT) //=======================================================================...
mit
Cuda
875e6e2460216274bf43a4a98e087142c5aa969f
Add interface.
nakdai/aten,nakdai/aten
src/libidaten/kernel/intersect.cuh
src/libidaten/kernel/intersect.cuh
#pragma once #include "kernel/context.cuh" #include <cuda_runtime.h> #include <device_launch_parameters.h> #include "cuda/helper_math.h" #include "aten4idaten.h" __device__ bool hitSphere( const aten::GeomParameter* shape, const aten::ray& r, float t_min, float t_max, aten::Intersection* isect); __device__ boo...
#pragma once #include "kernel/context.cuh" #include <cuda_runtime.h> #include <device_launch_parameters.h> #include "cuda/helper_math.h" #include "aten4idaten.h" __device__ bool hitSphere( const aten::GeomParameter* shape, const aten::ray& r, float t_min, float t_max, aten::Intersection* isect); __device__ boo...
mit
Cuda
54ee9390c39a442322beeb8897c4bed9be7a7519
Enable second bulk_invoke
egaburov/agency,egaburov/agency
cuda_grid.cu
cuda_grid.cu
#include <agency/cuda/execution_policy.hpp> #include <cstdio> struct kernel { __device__ void operator()(agency::parallel_group<agency::cuda::concurrent_agent>& self) { printf("hello from {%d, %d}\n", (int)self.outer().index(), (int)self.inner().index()); } __device__ void operator()(agency::parallel...
#include <agency/cuda/execution_policy.hpp> #include <cstdio> struct kernel { __device__ void operator()(agency::parallel_group<agency::cuda::concurrent_agent>& self) { printf("hello from {%d, %d}\n", (int)self.outer().index(), (int)self.inner().index()); } __device__ void operator()(agency::parallel...
bsd-3-clause
Cuda
e3e1e59f7592266b97578a14ec1c45de667e9124
Fix stack macro
sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet,sxjscience/mxnet
src/operator/deconvolution.cu
src/operator/deconvolution.cu
/*! * Copyright (c) 2015 by Contributors * \file deconvolution.cu * \brief * \author Wei Wu */ #include "./deconvolution-inl.h" #if MXNET_USE_CUDNN == 1 #include "./cudnn_deconvolution-inl.h" #endif // MXNET_USE_CUDNN namespace mxnet { namespace op { template<> Operator* CreateOp<gpu>(DeconvolutionParam param, i...
/*! * Copyright (c) 2015 by Contributors * \file deconvolution.cu * \brief * \author Wei Wu */ #include "./deconvolution-inl.h" #if MXNET_USE_CUDNN == 1 #include "./cudnn_deconvolution-inl.h" #endif // MXNET_USE_CUDNN namespace mxnet { namespace op { template<> Operator* CreateOp<gpu>(DeconvolutionParam param, i...
apache-2.0
Cuda
e3e3369dbfc4d2584905aa737679fc688555e77f
revert last change
GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC_Serial,GOMC-WSU/GOMC,GOMC-WSU/GOMC
src/GPU/CUDAMemoryManager.cuh
src/GPU/CUDAMemoryManager.cuh
#pragma once #ifdef GOMC_CUDA #include <cuda.h> #include <cuda_runtime.h> #include <unordered_map> #include <iostream> class CUDAMemoryManager { public: static void Init() { totalAllocatedBytes = 0; } static cudaError_t mallocMemory(void **address, unsigned int size); static cudaError_t freeMemory(void *address)...
#pragma once #ifdef GOMC_CUDA #include <cuda.h> #include <cuda_runtime.h> #include <unordered_map> #include <iostream> class CUDAMemoryManager { public: static void Init() { totalAllocatedBytes = 0; } static cudaError_t mallocMemory(void **address, unsigned int size); static cudaError_t freeMemory(void *address)...
mit
Cuda
9be1639bbed1f4f139c6f35ba731a885bb9e008f
Add scaling support to Occupancy kernel.
Christof/voly-labeller,Christof/voly-labeller,Christof/voly-labeller,Christof/voly-labeller
src/placement/occupancy.cu
src/placement/occupancy.cu
#include "./occupancy.h" #include "../utils/cuda_helper.h" __global__ void occupancyKernel(cudaTextureObject_t positions, cudaSurfaceObject_t output, int width, int height, float widthScale, float heightScale) { int x = blockIdx.x * blockDim.x + threadI...
#include "./occupancy.h" #include "../utils/cuda_helper.h" __global__ void occupancyKernel(cudaTextureObject_t positions, cudaSurfaceObject_t output, int width, int height) { int x = blockIdx.x * blockDim.x + threadIdx.x; int y = blockIdx.y * blockDim.y + threadIdx.y; if (x >= width || y >= height) retur...
mit
Cuda
7aab5835a082d123fbc9b99805bdd4b47169b77d
Initialize neurons at zero potential
schatten/moment,schatten/moment,schatten/moment
src/neuron.cuh
src/neuron.cuh
#ifndef MOMENT_CONNECTIONS #define MOMENT_CONNECTIONS #include <stdlib.h> // For rand() #include "defs.cuh" // Structure representing a connection. Has the id of the post // synaptic neuron and the axonal delay struct Connection { int neuron; int delay; }; /* Structure representing a neuron in the Izhikewich m...
#ifndef MOMENT_CONNECTIONS #define MOMENT_CONNECTIONS #include <stdlib.h> // For rand() #include "defs.cuh" // Structure representing a connection. Has the id of the post // synaptic neuron and the axonal delay struct Connection { int neuron; int delay; }; /* Structure representing a neuron in the Izhikewich m...
mit
Cuda
20336e3cafb994fb666986a006761b6b11ad5111
Add TestCountingIteratorLowerBound and mark it as KNOWN_FAILURE
jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust
testing/counting_iterator.cu
testing/counting_iterator.cu
#include <thrusttest/unittest.h> #include <thrust/iterator/counting_iterator.h> #include <thrust/sort.h> #include <thrust/binary_search.h> void TestCountingIteratorIncrement(void) { thrust::experimental::counting_iterator<int> iter(0); ASSERT_EQUAL(*iter, 0); iter++; ASSERT_EQUAL(*iter, 1); ...
#include <thrusttest/unittest.h> #include <thrust/iterator/counting_iterator.h> void TestCountingIteratorIncrement(void) { thrust::experimental::counting_iterator<int> iter(0); ASSERT_EQUAL(*iter, 0); iter++; ASSERT_EQUAL(*iter, 1); iter++; iter++; ASSERT_EQUAL(*iter, 3); ...
apache-2.0
Cuda
57506c6f4de6714d9cf0ef50bffb69c077eeea24
Update kWarpSize for A100 arch (#1380)
facebookresearch/faiss,facebookresearch/faiss,facebookresearch/faiss,facebookresearch/faiss
faiss/gpu/utils/DeviceDefs.cuh
faiss/gpu/utils/DeviceDefs.cuh
/** * Copyright (c) Facebook, Inc. and its affiliates. * * This source code is licensed under the MIT license found in the * LICENSE file in the root directory of this source tree. */ #pragma once #include <cuda.h> namespace faiss { namespace gpu { // We require at least CUDA 8.0 for compilation #if CUDA_VERS...
/** * Copyright (c) Facebook, Inc. and its affiliates. * * This source code is licensed under the MIT license found in the * LICENSE file in the root directory of this source tree. */ #pragma once #include <cuda.h> namespace faiss { namespace gpu { // We require at least CUDA 8.0 for compilation #if CUDA_VERS...
mit
Cuda
c1d3d19a7fa29a67b0a0c454ce65edfc50b26cd9
Improve vector_add example
thomasjo/cudalicious,thomasjo/cudalicious
example/vector_add/vector_add.cu
example/vector_add/vector_add.cu
#include <algorithm> #include <cassert> #include <cmath> #include <iostream> #include <random> #include <vector> #include <cudalicious/core.hpp> template<typename T> std::vector<T> operator+(const std::vector<T>& a, const std::vector<T>& b) { std::vector<T> result(a.size()); std::transform(a.begin(), a.end(), b.b...
#include <iostream> #include <random> #include <vector> #include <cudalicious/core.hpp> template<typename T> __global__ void add_kernel(T* c, const T* a, const T* b, const size_t n) { int idx = blockDim.x * blockIdx.x + threadIdx.x; if (idx < n) { c[idx] = a[idx] + b[idx]; } } template<typename T> std::vec...
mit
Cuda
491f000edaabf08fd9c6a5da52db2c37e773fa20
Make thrust.examples.uninitialized_vector happy with 10.1 allocators.
andrewcorrigan/thrust-multi-permutation-iterator,thrust/thrust,thrust/thrust,jaredhoberock/thrust,thrust/thrust,jaredhoberock/thrust,jaredhoberock/thrust,andrewcorrigan/thrust-multi-permutation-iterator,andrewcorrigan/thrust-multi-permutation-iterator,thrust/thrust,thrust/thrust,jaredhoberock/thrust,jaredhoberock/thrus...
examples/uninitialized_vector.cu
examples/uninitialized_vector.cu
// Occasionally, it is advantageous to avoid initializing the individual // elements of a device_vector. For example, the default behavior of // zero-initializing numeric data may introduce undesirable overhead. // This example demonstrates how to avoid default construction of a // device_vector's data by using a custo...
// Occasionally, it is advantageous to avoid initializing the individual // elements of a device_vector. For example, the default behavior of // zero-initializing numeric data may introduce undesirable overhead. // This example demonstrates how to avoid default construction of a // device_vector's data by using a custo...
apache-2.0
Cuda
216ad8fd15bbf68f2ed74394242734e8cd2521ab
fix long result array
bvanderhaar/cuda-musclework,bvanderhaar/cuda-musclework,bvanderhaar/cuda-musclework
main.cu
main.cu
#include <stdio.h> #include <stdlib.h> /* * In CUDA it is necessary to define block sizes * The grid of data that will be worked on is divided into blocks */ #define BLOCK_SIZE 8 __global__ void cu_dotProduct(int *distance_array_d, int *force_array_d, long long *result_array_d, int ma...
#include <stdio.h> #include <stdlib.h> /* * In CUDA it is necessary to define block sizes * The grid of data that will be worked on is divided into blocks */ #define BLOCK_SIZE 8 __global__ void cu_dotProduct(int *distance_array_d, int *force_array_d, long long *result_array_d, int ma...
mit
Cuda
b62aaf3d984c647a2fbab4a292ad1f11e6147abe
fix comment (#15481)
apache/incubator-mxnet,tlby/mxnet,ForkedReposBak/mxnet,yajiedesign/mxnet,yajiedesign/mxnet,reminisce/mxnet,reminisce/mxnet,leezu/mxnet,larroy/mxnet,larroy/mxnet,zhreshold/mxnet,zhreshold/mxnet,sxjscience/mxnet,reminisce/mxnet,eric-haibin-lin/mxnet,sxjscience/mxnet,zhreshold/mxnet,DickJC123/mxnet,ForkedReposBak/mxnet,re...
src/operator/tensor/elemwise_binary_op_extended.cu
src/operator/tensor/elemwise_binary_op_extended.cu
/* * Licensed to the Apache Software Foundation (ASF) under one * or more contributor license agreements. See the NOTICE file * distributed with this work for additional information * regarding copyright ownership. The ASF licenses this file * to you under the Apache License, Version 2.0 (the * "License"); you ...
/* * Licensed to the Apache Software Foundation (ASF) under one * or more contributor license agreements. See the NOTICE file * distributed with this work for additional information * regarding copyright ownership. The ASF licenses this file * to you under the Apache License, Version 2.0 (the * "License"); you ...
apache-2.0
Cuda
ca49b5dad4d243f6188dc45d7de312b51080ba8a
Change indentation to 2 spaces
gunrock/gunrock,gunrock/gunrock,gunrock/gunrock
unittests/device_properties/test_device_properties.cu
unittests/device_properties/test_device_properties.cu
#include <iostream> #include <string> #include <gunrock/cuda/device_properties.hxx> int main(int argc, char** argv) { using namespace std; using namespace gunrock::cuda; using namespace gunrock::cuda::properties; int cc_ver = (argc > 1) ? stoi(argv[1]) : 30; compute_capability_t cc = make_compute_capability...
#include <iostream> #include <string> #include <gunrock/cuda/device_properties.hxx> int main(int argc, char** argv) { using namespace std; using namespace gunrock::cuda; using namespace gunrock::cuda::properties; int cc_ver = (argc > 1) ? stoi(argv[1]) : 30; compute_capability_t cc = make_compute_...
apache-2.0
Cuda
b1d73e444ab19333b0d138e817552e5fa9fe331a
Remove an double include
TAdeJong/plasma-analysis,TAdeJong/plasma-analysis
code/coordfunctions.cu
code/coordfunctions.cu
#include "constants.cuh" #include "coordfunctions.cuh" #include "helper_math.h" __device__ float4 tex3D(texture<float4, 3, cudaReadModeElementType> tex, float3 a) { return tex3D(tex, a.x,a.y,a.z); } /* Converts a float4 of Smietcoordinates (values between origin (which is negative) and -origin) to a float3 of Textu...
#include "constants.cuh" #include "coordfunctions.cuh" #include "constants.cuh" #include "helper_math.h" __device__ float4 tex3D(texture<float4, 3, cudaReadModeElementType> tex, float3 a) { return tex3D(tex, a.x,a.y,a.z); } /* Converts a float4 of Smietcoordinates (values between origin (which is negative) and -orig...
mit
Cuda
e4c4fc5523dfcbad4efc78103cbb51ba34613f53
Fix failure in lit test kernel-call.cu
apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/cl...
test/CodeGenCUDA/kernel-call.cu
test/CodeGenCUDA/kernel-call.cu
// RUN: %clang_cc1 -emit-llvm %s -o - | FileCheck %s --check-prefixes=CUDA,CHECK // RUN: %clang_cc1 -x hip -emit-llvm %s -o - | FileCheck %s --check-prefixes=HIP,CHECK #include "Inputs/cuda.h" // CHECK-LABEL: define void @_Z2g1i // HIP: call{{.*}}hipSetupArgument // HIP: call{{.*}}hipLaunchByPtr // CUDA: call{{.*}}c...
// RUN: %clang_cc1 -emit-llvm %s -o - | FileCheck %s --check-prefixes=CUDA,CHECK // RUN: %clang_cc1 -x hip -emit-llvm %s -o - | FileCheck %s --check-prefixes=HIP,CHECK #include "Inputs/cuda.h" // CHECK-LABEL: define void @_Z2g1i(i32 %x) // HIP: call{{.*}}hipSetupArgument // HIP: call{{.*}}hipLaunchByPtr // CUDA: cal...
apache-2.0
Cuda
c74cc023a095a7496f70871377f3e71fce169198
Add test for exception
termoshtt/cujak,termoshtt/cujak
util/CUDA/test/exception.cu
util/CUDA/test/exception.cu
#include "../exception.hpp" #include <iostream> namespace U = cujak::util; void test_exception(cudaError_t err) { try { CUDA_EXEC(err); } catch (U::CUDA_ERROR &e) { std::cout << "Error type: " << e.err << '\n' << "Error occured at " << e.filename << ":" << e.line << ":" << e.funcname << '...
#include "../exception.hpp" int main(int argc, char const *argv[]) { return 0; }
bsd-2-clause
Cuda
f5b53d888e5e05d64af3ae42d933157361de4d9e
Test set_difference with thrust::device in __device__ code.
jaredhoberock/thrust,xiongzhanblake/thrust,Ricardo666666/thrust,thvasilo/thrust,xiongzhanblake/thrust_src,xiongzhanblake/thrust,andrewcorrigan/thrust-multi-permutation-iterator,mohamed-ali/thrust,GrimDerp/thrust,jaredhoberock/thrust,andrewcorrigan/thrust-multi-permutation-iterator,xiongzhanblake/thrust_src,sdalton1/thr...
testing/backend/cuda/set_difference.cu
testing/backend/cuda/set_difference.cu
#include <unittest/unittest.h> #include <thrust/set_operations.h> #include <thrust/execution_policy.h> template<typename ExecutionPolicy, typename Iterator1, typename Iterator2, typename Iterator3, typename Iterator4> __global__ void set_difference_kernel(ExecutionPolicy exec, Iterator1 first1, Iterator1 last1, Itera...
#include <unittest/unittest.h> #include <thrust/set_operations.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2, typename Iterator3, typename Iterator4> __global__ void set_difference_kernel(Iterator1 first1, Iterator1 last1, Iterator2 first2, Iterator2 last2, Iterator3 result1,...
apache-2.0
Cuda
3d6af3f0b119303e5299c9155ffe8d4fb285bb72
Test host_system_tag rather than cpp::tag
zeryx/thrust,thrust/thrust,xiongzhanblake/thrust_src,raygit/thrust,zhenglaizhang/thrust,egaburov/thrust,arnabgho/thrust,dachziegel/thrust,sarvex/thrust,zeryx/thrust,sdalton1/thrust,jaredhoberock/thrust,GrimDerp/thrust,thrust/thrust,dachziegel/thrust,mohamed-ali/thrust,marksantos/thrust,thrust/thrust,jaredhoberock/thrus...
testing/backend/cuda/memory.cu
testing/backend/cuda/memory.cu
#include <unittest/unittest.h> #include <thrust/system/cuda/memory.h> template<typename T1, typename T2> bool is_same(const T1 &, const T2 &) { return false; } template<typename T> bool is_same(const T &, const T &) { return true; } void TestSelectSystemCudaToCpp() { using thrust::system::detail::generic::sele...
#include <unittest/unittest.h> #include <thrust/system/cuda/memory.h> template<typename T1, typename T2> bool is_same(const T1 &, const T2 &) { return false; } template<typename T> bool is_same(const T &, const T &) { return true; } void TestSelectSystemCudaToCpp() { using thrust::system::detail::generic::sele...
apache-2.0
Cuda
58b37f720059b9953e28ea1c4ee0d2b66ccb8018
Implement random number generation
RichieSams/rapt,RichieSams/rapt
source/basic_path_tracer/path_trace.cu
source/basic_path_tracer/path_trace.cu
/* raic - RichieSam's Adventures in Cuda * * raic is the legal property of Adrian Astley * Copyright Adrian Astley 2015 */ #include "basic_path_tracer/path_trace.cuh" #include <device_launch_parameters.h> #include <graphics/helper_math.h> #include <curand_kernel.h> __device__ float3 CalculateRayDirectionFromPix...
/* raic - RichieSam's Adventures in Cuda * * raic is the legal property of Adrian Astley * Copyright Adrian Astley 2015 */ #include "basic_path_tracer/path_trace.cuh" #include <device_launch_parameters.h> #include <graphics/helper_math.h> #include <curand_kernel.h> __device__ float3 CalculateRayDirectionFromPix...
apache-2.0
Cuda
83d61b5f72d6ab7b8ba2fe40a7fabe03f2ae128c
Update vectoradd_cuda.cu
3upperm2n/cuMatlab
cudakernels/vectoradd_cuda.cu
cudakernels/vectoradd_cuda.cu
#include "mex.h" #include <cuda_runtime.h> #include <helper_cuda.h> #include <helper_functions.h> inline int BLK(int number, int blksize) { return (number + blksize ...
#include "mex.h" #include <cuda_runtime.h> #include <helper_cuda.h> #include <helper_functions.h> inline int BLK(int number, int blksize) { return (number + blksize ...
mit
Cuda
dc6a541e610e1a74866d28e5c1fd3e5a2db7cafe
remove use of float2 from bounding box example
jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust
examples/bounding_box.cu
examples/bounding_box.cu
#include <thrust/transform_reduce.h> #include <thrust/device_vector.h> #include <thrust/pair.h> #include <stdlib.h> // for rand() // This example shows how to compute a bounding box // for a set of points in two dimensions. struct point2d { float x, y; __host__ __device__ point2d() {} __host_...
#include <thrust/transform_reduce.h> #include <thrust/device_vector.h> #include <thrust/pair.h> #include <cuda.h> // for float2 #include <stdlib.h> // for rand() // This example shows how to compute a bounding box // for a set of points in two dimensions. // bounding box type typedef thrust::pair<float2, float...
apache-2.0
Cuda
e9bc38f0747da15231051c12599e7d139c788f50
Test partition_point with thrust::device in __device__ code.
raygit/thrust,thrust/thrust,mohamed-ali/thrust,dachziegel/thrust,jaredhoberock/thrust,thrust/thrust,sdalton1/thrust,sdalton1/thrust,egaburov/thrust,Ricardo666666/thrust,thrust/thrust,dachziegel/thrust,xiongzhanblake/thrust,sdalton1/thrust,zhenglaizhang/thrust,Ricardo666666/thrust,jaredhoberock/thrust,thvasilo/thrust,Gr...
testing/backend/cuda/partition_point.cu
testing/backend/cuda/partition_point.cu
#include <unittest/unittest.h> #include <thrust/partition.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename ExecutionPolicy, typename Iterator1, typename Predicate, typename Iterator2> __global__ void partition_point_kernel(ExecutionPolicy exec, Iterator1 first, Iterator1 last, ...
#include <unittest/unittest.h> #include <thrust/partition.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Predicate, typename Iterator2> __global__ void partition_point_kernel(Iterator1 first, Iterator1 last, Predicate pred, Iterator2 result) { *result = ...
apache-2.0
Cuda
2df5977c5f8cc99ad7396b1b72a34e4b7d260b6d
add macro to print debug info
rk0der/railgun,rk0der/railgun,rk0der/railgun
src/util.cu
src/util.cu
#include "railgun.h" #include <stdio.h> #define print_header(typename, len)\ printf("\ttype: %s\n", typename);\ printf("\tlength: %d\n", len); #define print_values(format, ptr, len)\ printf("\tvalues:\n");\ for (int i = 0; i < len; i++) {\ printf("\t\t");\ printf(format, ptr[i]);\ printf("\n");} v...
#include "railgun.h" #include <stdio.h> void dump_args(railgun_args* args) { int i; printf("railgun_args:\n"); printf("argc: %d\n", args->argc); for (i = 0; i < args->argc; i++) { railgun_data v; printf("argv[%d]:\n", i); v = args->argv[i]; switch (v.type) { case TYPE_INT_P: int *p;...
mit
Cuda
b5abb749a381c08fd499743871896b620f133d3b
Implement 2-dimensional grids, but leave commented out
egaburov/agency,egaburov/agency
cuda_grid.cu
cuda_grid.cu
#include <agency/cuda/execution_policy.hpp> #include <cstdio> struct kernel { __device__ void operator()(agency::parallel_group<agency::cuda::concurrent_agent>& self) { printf("hello from {%d, %d}\n", (int)self.outer().index(), (int)self.inner().index()); } __device__ void operator()(agency::parallel...
#include <agency/cuda/execution_policy.hpp> #include <cstdio> struct kernel { __device__ void operator()(agency::parallel_group<agency::cuda::concurrent_agent>& self) { printf("hello from {%d, %d}\n", (int)self.outer().index(), (int)self.inner().index()); } }; auto grid(size_t num_blocks, size_t num_thre...
bsd-3-clause
Cuda
99ca83b622cd0eab3dfcbc67e981efe5cbd0ece8
Tidy up.
SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC
MS3/Sketches/GCF_new/dbl_max.cu
MS3/Sketches/GCF_new/dbl_max.cu
#include "threadFenceReduction_kernel.cuh" #include <math_functions.h> struct doubleMax { TASKCFG double init() {return 0.0;} TASKCFG double reduce(double x, double acc){return max(x,acc);} TASKCFG double f(unsigned int, double c){return fabs(c);} }; extern "C" __global__ void max_512_e2(const double *g_idata,...
#include "threadFenceReduction_kernel.cuh" #include <math_functions.h> struct doubleMax { TASKCFG double init() {return 0.0;} TASKCFG double reduce(double x, double acc){return max(x,acc);} TASKCFG double f(unsigned int i, double c){return fabs(c);} }; extern "C" __global__ void max_512_e2(const double *g_idat...
apache-2.0
Cuda
3d94f546cecca4f8144ceb74db7762e305f5de4f
Abort if no scheduler for exponential smoothing
amunmt/marian,amunmt/marian,emjotde/amunn,marian-nmt/marian-train,marian-nmt/marian-train,emjotde/amunmt,amunmt/marian,emjotde/amunn,emjotde/amunn,emjotde/amunmt,marian-nmt/marian-train,marian-nmt/marian-train,emjotde/Marian,emjotde/amunmt,emjotde/Marian,emjotde/amunn,marian-nmt/marian-train,emjotde/amunmt
src/training/graph_group_singleton.cu
src/training/graph_group_singleton.cu
#include "kernels/tensor_operators.h" #include "training/graph_group_singleton.h" namespace marian { void SingletonGraph::setScheduler(Ptr<Scheduler> scheduler) { scheduler_ = scheduler; // optimizer has to be registered last to see changes of learning rate scheduler_->registerTrainingObserver(scheduler_); sc...
#include "kernels/tensor_operators.h" #include "training/graph_group_singleton.h" namespace marian { void SingletonGraph::setScheduler(Ptr<Scheduler> scheduler) { scheduler_ = scheduler; // optimizer has to be registered last to see changes of learning rate scheduler_->registerTrainingObserver(scheduler_); sc...
mit
Cuda
59e668debfadd08b69367e19f3bdefe7934130cd
Migrate lexicographical_sort to thrust::next::gather.
thrust/thrust,andrewcorrigan/thrust-multi-permutation-iterator,thvasilo/thrust,xiongzhanblake/thrust,andrewcorrigan/thrust-multi-permutation-iterator,thvasilo/thrust,arnabgho/thrust,egaburov/thrust,marksantos/thrust,sarvex/thrust,sdalton1/thrust,xiongzhanblake/thrust,sarvex/thrust,thrust/thrust,jaredhoberock/thrust,jar...
examples/lexicographical_sort.cu
examples/lexicographical_sort.cu
#include <thrust/host_vector.h> #include <thrust/device_vector.h> #include <thrust/generate.h> #include <thrust/sequence.h> #include <thrust/sort.h> #include <thrust/gather.h> #include <iostream> #include <cstdlib> // This example shows how to perform a lexicographical sort on multiple keys. // // http://en.wikipedia....
#include <thrust/host_vector.h> #include <thrust/device_vector.h> #include <thrust/generate.h> #include <thrust/sequence.h> #include <thrust/sort.h> #include <thrust/gather.h> #include <iostream> #include <cstdlib> // This example shows how to perform a lexicographical sort on multiple keys. // // http://en.wikipedia....
apache-2.0
Cuda
715ac3629830367768419ba4f9c1b4057430ece9
Prepare NVidia gridder's Halide veneer to be used as drop-in replacement for the true Halide kernels.
SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC,SKA-ScienceDataProcessor/RC
MS6/kernel/nvidia/gridder/halide_api.cu
MS6/kernel/nvidia/gridder/halide_api.cu
#include "grid_gpu.cuh" #include "halide_buf.h" extern "C" int nvGridder(const double _scale, const int32_t _grid_size, buffer_t *_vis_buffer, buffer_t *_gcf_buffer, buffer_t *_uvg_buffer){ // FIXME: make gridGPUx respect buffers locations, i.e. // to check if they already are on GPU and skip allocation and marsha...
#include "grid_gpu.cuh" #include "halide_buf.h" extern "C" int nvGridder(const double _scale, const int32_t _grid_size, buffer_t *_vis_buffer, buffer_t *_gcf_buffer, buffer_t *_uvg_buffer){ gridGPUc( _scale , reinterpret_cast<CmplxType*>(_uvg_buffer->host) , reinterpret_cast<combined*>(_vis_buffe...
apache-2.0
Cuda
7a6d838639c458942a133784e392c4030836056f
Fix missed name change
joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue
hoomd/md/ExpandedMieDriverPotentialPairGPU.cu
hoomd/md/ExpandedMieDriverPotentialPairGPU.cu
// Copyright (c) 2009-2021 The Regents of the University of Michigan // This file is part of the HOOMD-blue project, released under the BSD 3-Clause License. /*! \file ExpandedMieDriverPotentialPairGPU.cu \brief Defines the driver functions for computing all types of pair forces on the GPU */ #include "AllDriverP...
// Copyright (c) 2009-2021 The Regents of the University of Michigan // This file is part of the HOOMD-blue project, released under the BSD 3-Clause License. /*! \file ExpandedMieDriverPotentialPairGPU.cu \brief Defines the driver functions for computing all types of pair forces on the GPU */ #include "AllDriverP...
bsd-3-clause
Cuda
8f4c31fb3a3e3863066d069568e8dc11980be8a4
add inline distance2
stormHan/Parallel_RVD,stormHan/Parallel_RVD
Parallel_RVD/Math_basics.cuh
Parallel_RVD/Math_basics.cuh
#ifndef H_CUDA_BASCIS_H #define H_CUDA_BASCIS_H __device__ double computeDistance(double3 p1, double3 p2) { return sqrt((p1.x - p2.x) * (p1.x - p2.x) + (p1.y - p2.y) * (p1.y - p2.y) + (p1.z - p2.z) * (p1.z - p2.z)); } __device__ inline double sqr_d(double x) { return x * x; } __device__ inline double distan...
#ifndef H_CUDA_BASCIS_H #define H_CUDA_BASCIS_H __device__ double computeDistance(double3 p1, double3 p2) { return sqrt((p1.x - p2.x) * (p1.x - p2.x) + (p1.y - p2.y) * (p1.y - p2.y) + (p1.z - p2.z) * (p1.z - p2.z)); } __device__ double3 add(double3 a, double3 b) { a.x = a.x + b.x; a.y = a.y + b.y; a.z = a...
mit
Cuda
d9ac475a4552da70b51dafcaca6ca105c0c75862
Add frequency-generator program file
schatten/moment,schatten/moment,schatten/moment
test/frequency-generator.cu
test/frequency-generator.cu
/* Utility program. Create sinusoidal outputs given an input of the frequency * in Hz. The output is a mili-second sampling of such a sinusoidal signal. */ #include <stdio.h> #include <stdlib.h> #include <limits.h> #include <math.h> #define PI 3.1415926535897 int create_pattern(int frequency, int count) { float c...
/* Utility program. Create sinusoidal outputs given an input of the frequency * in Hz. The output is a mili-second sampling of such a sinusoidal signal. */ #include <stdio.h> #include <stdlib.h> #include <limits.h> #include <math.h> #define PI 3.1415926535897 int create_pattern(int frequency, int count) { float c...
mit
Cuda
c08752ca43fe0e81f4a327b42e0e159be0bc2af4
Fix compile error
chengduoZH/Paddle,reyoung/Paddle,baidu/Paddle,luotao1/Paddle,luotao1/Paddle,reyoung/Paddle,pkuyym/Paddle,tensor-tang/Paddle,Canpio/Paddle,jacquesqiao/Paddle,luotao1/Paddle,putcn/Paddle,tensor-tang/Paddle,chengduoZH/Paddle,PaddlePaddle/Paddle,Canpio/Paddle,jacquesqiao/Paddle,pkuyym/Paddle,QiJune/Paddle,pkuyym/Paddle,luo...
paddle/fluid/framework/tensor_util_test.cu
paddle/fluid/framework/tensor_util_test.cu
/* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserved. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applic...
/* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserved. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applic...
apache-2.0
Cuda
d7ca48396062c94db294cbd9aa56d149fd7b2204
Fix error message typo in SoftmaxWithLossLayer
minghuam/caffe,nicodjimenez/caffe,audtlr24/caffe,vibhav-vineet/caffe,sguada/caffe-public,naeluh/caffe,xidianwlc/caffe,minghuam/caffe,pcoving/caffe,dculibrk/boosted_pooling,wangg12/caffe,xidianwlc/caffe,CVML/sds_eccv2014,dculibrk/boosted_pooling,niuzhiheng/caffe,dylansun/caffe,intelcaffe/caffe-old,dculibrk/boosted_pooli...
src/caffe/layers/softmax_loss_layer.cu
src/caffe/layers/softmax_loss_layer.cu
// Copyright 2013 Yangqing Jia #include <algorithm> #include <cfloat> #include <vector> #include "caffe/layer.hpp" #include "caffe/vision_layers.hpp" #include "caffe/util/math_functions.hpp" using std::max; namespace caffe { template <typename Dtype> void SoftmaxWithLossLayer<Dtype>::SetUp(const vector<Blob<Dtype>...
// Copyright 2013 Yangqing Jia #include <algorithm> #include <cfloat> #include <vector> #include "caffe/layer.hpp" #include "caffe/vision_layers.hpp" #include "caffe/util/math_functions.hpp" using std::max; namespace caffe { template <typename Dtype> void SoftmaxWithLossLayer<Dtype>::SetUp(const vector<Blob<Dtype>...
bsd-2-clause
Cuda
a778de45d2d44a6fe116810919ad82f72691325c
Add comments to further explain the file arraignment of the kernel code
RichieSams/rapt,RichieSams/rapt
source/basic_path_tracer/cuda_kernel_call_wrapper.cu
source/basic_path_tracer/cuda_kernel_call_wrapper.cu
/* rapt - RichieSam's Adventures in Path Tracing * * rapt is the legal property of Adrian Astley * Copyright Adrian Astley 2015 */ #include "basic_path_tracer/path_trace.cuh" uint32 WangHash(uint32 a) { a = (a ^ 61) ^ (a >> 16); a = a + (a << 3); a = a ^ (a >> 4); a = a * 0x27d4eb2d; a = a ^ ...
/* rapt - RichieSam's Adventures in Path Tracing * * rapt is the legal property of Adrian Astley * Copyright Adrian Astley 2015 */ #include "basic_path_tracer/path_trace.cuh" uint32 WangHash(uint32 a) { a = (a ^ 61) ^ (a >> 16); a = a + (a << 3); a = a ^ (a >> 4); a = a * 0x27d4eb2d; a = a ^ ...
apache-2.0
Cuda
9222593fc22d72676e1f1f8b224464ffd326d607
Fix lit test kernel-call.cu failure on ps4 due to dso_local
apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-cl...
test/CodeGenCUDA/kernel-call.cu
test/CodeGenCUDA/kernel-call.cu
// RUN: %clang_cc1 -emit-llvm %s -o - | FileCheck %s --check-prefixes=CUDA,CHECK // RUN: %clang_cc1 -x hip -emit-llvm %s -o - | FileCheck %s --check-prefixes=HIP,CHECK #include "Inputs/cuda.h" // CHECK-LABEL: define{{.*}} void @_Z2g1i // HIP: call{{.*}}hipSetupArgument // HIP: call{{.*}}hipLaunchByPtr // CUDA: call{...
// RUN: %clang_cc1 -emit-llvm %s -o - | FileCheck %s --check-prefixes=CUDA,CHECK // RUN: %clang_cc1 -x hip -emit-llvm %s -o - | FileCheck %s --check-prefixes=HIP,CHECK #include "Inputs/cuda.h" // CHECK-LABEL: define void @_Z2g1i // HIP: call{{.*}}hipSetupArgument // HIP: call{{.*}}hipLaunchByPtr // CUDA: call{{.*}}c...
apache-2.0
Cuda
07f5db125aae68867a3588b76c59507c9e42b402
Fix printf for size_t values in cuda_device_info
darkbuck/Halide,Trass3r/Halide,darkbuck/Halide,Trass3r/Halide,darkbuck/Halide,Trass3r/Halide,darkbuck/Halide,darkbuck/Halide,Trass3r/Halide,Trass3r/Halide,darkbuck/Halide,Trass3r/Halide,darkbuck/Halide,Trass3r/Halide
experiments/cuda_device_info.cu
experiments/cuda_device_info.cu
#include <stdio.h> // Print device properties void printDevProp(cudaDeviceProp devProp) { printf("Major revision number: %d\n", devProp.major); printf("Minor revision number: %d\n", devProp.minor); printf("Name: %s\n", devProp.name); printf("Total global memo...
#include <stdio.h> // Print device properties void printDevProp(cudaDeviceProp devProp) { printf("Major revision number: %d\n", devProp.major); printf("Minor revision number: %d\n", devProp.minor); printf("Name: %s\n", devProp.name); printf("Total global memo...
mit
Cuda
05cbd4daacb699ec94d77f5b0229aaaa16c35af1
fix format
baidu/Paddle,lcy-seso/Paddle,jacquesqiao/Paddle,pengli09/Paddle,lcy-seso/Paddle,tensor-tang/Paddle,pengli09/Paddle,Canpio/Paddle,putcn/Paddle,PaddlePaddle/Paddle,pkuyym/Paddle,putcn/Paddle,QiJune/Paddle,reyoung/Paddle,PaddlePaddle/Paddle,pengli09/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,pkuyym/Paddle,putcn/Paddle,luot...
paddle/operators/adagrad_op.cu
paddle/operators/adagrad_op.cu
/* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applica...
/* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applica...
apache-2.0
Cuda
9e7364c8b9df96e1fb5d2874b5707c0f0010ae4a
Migrate lexicographical_sort to thrust::next::gather.
jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust,jbrownbridge/thrust
examples/lexicographical_sort.cu
examples/lexicographical_sort.cu
#include <thrust/host_vector.h> #include <thrust/device_vector.h> #include <thrust/generate.h> #include <thrust/sequence.h> #include <thrust/sort.h> #include <thrust/gather.h> #include <iostream> #include <cstdlib> // This example shows how to perform a lexicographical sort on multiple keys. // // http://en.wikipedia....
#include <thrust/host_vector.h> #include <thrust/device_vector.h> #include <thrust/generate.h> #include <thrust/sequence.h> #include <thrust/sort.h> #include <thrust/gather.h> #include <iostream> #include <cstdlib> // This example shows how to perform a lexicographical sort on multiple keys. // // http://en.wikipedia....
apache-2.0
Cuda
be7734ffb2438c3d8b95866c10e866777cbc5bc0
Clarify cuda backend example
ddemidov/amgcl,dondieselkopf/amgcl,ddemidov/amgcl,ddemidov/amgcl,huahbo/amgcl,huahbo/amgcl,dondieselkopf/amgcl,ddemidov/amgcl,huahbo/amgcl,dondieselkopf/amgcl
examples/cuda.cu
examples/cuda.cu
#include <iostream> #include <thrust/device_vector.h> #include <amgcl/amgcl.hpp> #include <amgcl/coarsening/smoothed_aggregation.hpp> #include <amgcl/relaxation/spai0.hpp> #include <amgcl/solver/bicgstab.hpp> #include <amgcl/backend/cuda.hpp> #include <amgcl/adapter/crs_tuple.hpp> #include <amgcl/profiler.hpp> #inc...
#include <iostream> #include <amgcl/amgcl.hpp> #include <amgcl/coarsening/smoothed_aggregation.hpp> #include <amgcl/relaxation/spai0.hpp> #include <amgcl/solver/bicgstab.hpp> #include <amgcl/backend/cuda.hpp> #include <amgcl/profiler.hpp> #include "sample_problem.hpp" namespace amgcl { profiler<> prof("v2"); ...
mit
Cuda
86eb6c72ffea9e41b5ca9950013a0ccfa6de7251
remove duplicate according to a review comment
cupy/cupy,cupy/cupy,cupy/cupy,cupy/cupy
cupy/core/include/cupy/atomics.cuh
cupy/core/include/cupy/atomics.cuh
#pragma once #if __CUDA_ARCH__ < 600 __device__ double atomicAdd(double *address, double val) { unsigned long long int* address_as_ull = (unsigned long long int*)address; unsigned long long int old = *address_as_ull; unsigned long long int assumed; do { assumed = old; old = atomicCAS(address_as_ull,...
#pragma once #if __CUDA_ARCH__ < 600 __device__ double atomicAdd(double *address, double val) { unsigned long long int* address_as_ull = (unsigned long long int*)address; unsigned long long int old = *address_as_ull; unsigned long long int assumed; do { assumed = old; old = atomicCAS(address_as_ull,...
mit
Cuda
aff90d8ee78be398b2984d63f2eb985f15f430d1
fix gpu build error
pengli09/Paddle,reyoung/Paddle,PaddlePaddle/Paddle,Canpio/Paddle,Canpio/Paddle,chengduoZH/Paddle,baidu/Paddle,yu239/Paddle,QiJune/Paddle,hedaoyuan/Paddle,lcy-seso/Paddle,pengli09/Paddle,chengduoZH/Paddle,lispc/Paddle,luotao1/Paddle,yu239/Paddle,pengli09/Paddle,pengli09/Paddle,jacquesqiao/Paddle,PaddlePaddle/Paddle,yu23...
paddle/operators/gaussian_random_op.cu
paddle/operators/gaussian_random_op.cu
/* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable...
/* Copyright (c) 2016 PaddlePaddle Authors. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable...
apache-2.0
Cuda
0158fa19f28619886232defd412433974af89611
Include "version.cuh" from "util_namespace.cuh" so that we can include a header that has always existed in Thrust when checking for older versions of CUB.
NVIDIA/cub,NVlabs/CUB,NVlabs/cub
cub/util_namespace.cuh
cub/util_namespace.cuh
/****************************************************************************** * Copyright (c) 2011, Duane Merrill. All rights reserved. * Copyright (c) 2011-2018, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provid...
/****************************************************************************** * Copyright (c) 2011, Duane Merrill. All rights reserved. * Copyright (c) 2011-2018, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provid...
bsd-3-clause
Cuda
092d496fbd1167e03833c8fd76ff1b63e24f0287
Test swap_ranges with thrust::device in __device__ code.
mohamed-ali/thrust,zeryx/thrust,marksantos/thrust,xiongzhanblake/thrust,marksantos/thrust,arnabgho/thrust,raygit/thrust,egaburov/thrust,zeryx/thrust,jaredhoberock/thrust,jaredhoberock/thrust,GrimDerp/thrust,arnabgho/thrust,zeryx/thrust,thvasilo/thrust,Ricardo666666/thrust,mohamed-ali/thrust,dachziegel/thrust,zhenglaizh...
testing/backend/cuda/swap_ranges.cu
testing/backend/cuda/swap_ranges.cu
#include <unittest/unittest.h> #include <thrust/swap.h> #include <thrust/execution_policy.h> template<typename ExecutionPolicy, typename Iterator1, typename Iterator2> __global__ void swap_ranges_kernel(ExecutionPolicy exec, Iterator1 first1, Iterator1 last1, Iterator2 first2) { thrust::swap_ranges(exec, first1, la...
#include <unittest/unittest.h> #include <thrust/swap.h> #include <thrust/execution_policy.h> template<typename Iterator1, typename Iterator2> __global__ void swap_ranges_kernel(Iterator1 first1, Iterator1 last1, Iterator2 first2) { thrust::swap_ranges(thrust::seq, first1, last1, first2); } void TestSwapRangesDevi...
apache-2.0
Cuda
07b03b6fcfadd1e67f7f229e011b0655d1940ce4
Fix flag name in comment in cuda-version-check.cu.
llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-cl...
test/Driver/cuda-version-check.cu
test/Driver/cuda-version-check.cu
// REQUIRES: clang-driver // REQUIRES: x86-registered-target // REQUIRES: nvptx-registered-target // RUN: %clang -v -### --cuda-gpu-arch=sm_20 --sysroot=%S/Inputs/CUDA 2>&1 %s | \ // RUN: FileCheck %s --check-prefix=OK // RUN: %clang -v -### --cuda-gpu-arch=sm_20 --sysroot=%S/Inputs/CUDA_80 2>&1 %s | \ // RUN: F...
// REQUIRES: clang-driver // REQUIRES: x86-registered-target // REQUIRES: nvptx-registered-target // RUN: %clang -v -### --cuda-gpu-arch=sm_20 --sysroot=%S/Inputs/CUDA 2>&1 %s | \ // RUN: FileCheck %s --check-prefix=OK // RUN: %clang -v -### --cuda-gpu-arch=sm_20 --sysroot=%S/Inputs/CUDA_80 2>&1 %s | \ // RUN: F...
apache-2.0
Cuda
5139b67d6025919aaebf45c81b517ed93b49716e
Remove debugging code from class_arg_kernel.cuh
NVIDIA/jitify,NVIDIA/jitify
example_headers/class_arg_kernel.cuh
example_headers/class_arg_kernel.cuh
/* * Copyright (c) 2017-2020, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions * are met: * * Redistributions of source code must retain the above copyright * notice, this list of...
/* * Copyright (c) 2017-2020, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions * are met: * * Redistributions of source code must retain the above copyright * notice, this list of...
bsd-3-clause
Cuda
bd214bc3645a3f4a4003f5e50264fedabdf32166
add vector initialization and outputting - sssp appears broken
RoyalCaliber/vertexAPI2,RoyalCaliber/vertexAPI2,RoyalCaliber/vertexAPI2
sssp.cu
sssp.cu
//Single source shortest paths using vertexAPI2 #include "util.h" #include "graphio.h" #include "refgas.h" struct SSSP { struct VertexData { int dist; }; struct EdgeData { int length; }; typedef int GatherResult; static int gatherZero; //this should be set to nVertices + 1 static int g...
//Single source shortest paths using vertexAPI2 #include "util.h" #include "graphio.h" #include "refgas.h" struct SSSP { struct VertexData { int dist; }; struct EdgeData { int length; }; typedef int GatherResult; static int gatherZero; //this should be set to nVertices + 1 static int g...
apache-2.0
Cuda
402e8a424b87c21ec68668dbfc7940153e88e5bd
Check with factories instead of values
egaburov/agency,egaburov/agency
testing/cuda/test_grid_executor_member_detection.cu
testing/cuda/test_grid_executor_member_detection.cu
#include <agency/cuda/grid_executor.hpp> #include <agency/executor_traits.hpp> #include <iostream> struct functor_returning_int { template<class... Args> __host__ __device__ int operator()(Args&&...) const { return 0; } }; struct functor_returning_void { template<class T> __host__ __device__ void ...
#include <agency/cuda/grid_executor.hpp> #include <agency/executor_traits.hpp> #include <iostream> struct functor_returning_int { template<class... Args> __host__ __device__ int operator()(Args&&...) const { return 0; } }; struct functor_returning_void { template<class T> __host__ __device__ void ...
bsd-3-clause
Cuda
02bf7f4eee8b80aa00452d5120fd0dd2dc259216
Use begin + 5 instead of end in examples/complicated_transform.cu
google-code-export/thrust,h1arshad/thrust,allendaicool/thrust,Vishwa07/thrust,julianromera/thrust,rdmenezes/thrust,Vishwa07/thrust,h1arshad/thrust,malenie/thrust,UIKit0/thrust,levendlee/thrust,google-code-export/thrust,hemmingway/thrust,lishi0927/thrust,levendlee/thrust,malenie/thrust,hemmingway/thrust,rdmenezes/thrust...
examples/complicated_transformation.cu
examples/complicated_transformation.cu
#include <thrust/for_each.h> #include <thrust/iterator/counting_iterator.h> #include <thrust/generate.h> #include <thrust/iterator/iterator_traits.h> #include <thrust/device_ptr.h> #include <thrust/host_vector.h> #include <thrust/device_vector.h> #include <iostream> #include <cstdlib> // this example shows how to impl...
#include <thrust/for_each.h> #include <thrust/iterator/counting_iterator.h> #include <thrust/generate.h> #include <thrust/iterator/iterator_traits.h> #include <thrust/device_ptr.h> #include <thrust/host_vector.h> #include <thrust/device_vector.h> #include <iostream> #include <cstdlib> // this example shows how to impl...
apache-2.0
Cuda
3a0756c2d8188619bf5f40bc12aaebd36409ba63
use cujak::complex
termoshtt/cujak,termoshtt/cujak
cufft/test/convert.cu
cufft/test/convert.cu
#include "../Converter.hpp" #include "../../thrust.hpp" #include <fstream> #include <iomanip> typedef typename cujak::traits<float>::Real Real; typedef typename cujak::traits<float>::Complex Complex; typedef thrust::device_vector<Real> Vector; typedef thrust::device_vector<Complex> cVector; typedef thrust::host_vecto...
#include "../Converter.hpp" #include <fstream> #include <iomanip> typedef typename cujak::traits<float>::Real Real; typedef typename cujak::traits<float>::Complex Complex; typedef thrust::device_vector<Real> Vector; typedef thrust::device_vector<Complex> cVector; typedef thrust::host_vector<Real> hVector; typedef thr...
bsd-2-clause
Cuda
cb50e4582fdd9005fd10fc0b831288fe46a9890f
Bump version to 1.12.0.
NVlabs/cub,NVIDIA/cub,NVlabs/CUB
cub/version.cuh
cub/version.cuh
/****************************************************************************** * Copyright (c) 2011-2020, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions are met: * * Redistrib...
/****************************************************************************** * Copyright (c) 2011-2020, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions are met: * * Redistrib...
bsd-3-clause
Cuda
eea428b036d35e75d178ecaa134f01c3d4c7de0d
Fix gpu compile
joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue,joaander/hoomd-blue
hoomd/hpmc/all_kernels_union_sphere.cu
hoomd/hpmc/all_kernels_union_sphere.cu
// Copyright (c) 2009-2016 The Regents of the University of Michigan // This file is part of the HOOMD-blue project, released under the BSD 3-Clause License. #include "ComputeFreeVolumeGPU.cuh" #include "IntegratorHPMCMonoGPU.cuh" #include "IntegratorHPMCMonoImplicitGPU.cuh" #include "ShapeUnion.h" namespace hpmc { ...
// Copyright (c) 2009-2016 The Regents of the University of Michigan // This file is part of the HOOMD-blue project, released under the BSD 3-Clause License. #include "ComputeFreeVolumeGPU.cuh" #include "IntegratorHPMCMonoGPU.cuh" #include "IntegratorHPMCMonoImplicitGPU.cuh" #include "ShapeUnion.h" namespace hpmc { ...
bsd-3-clause
Cuda
01a2de3c13e2bf354039ba840d7ef1b161996369
Fix the order of parameters given to then_execute()
egaburov/agency,egaburov/agency
test_then_execute.cu
test_then_execute.cu
#include <agency/executor_traits.hpp> #include <agency/sequential_executor.hpp> #include <agency/parallel_executor.hpp> #include <agency/concurrent_executor.hpp> #include <agency/cuda/grid_executor.hpp> #include <mutex> #include <thread> #include <cassert> template<class Executor, class Shape> void test_host(Shape sha...
#include <agency/executor_traits.hpp> #include <agency/sequential_executor.hpp> #include <agency/parallel_executor.hpp> #include <agency/concurrent_executor.hpp> #include <agency/cuda/grid_executor.hpp> #include <mutex> #include <thread> #include <cassert> template<class Executor, class Shape> void test_host(Shape sha...
bsd-3-clause
Cuda
f6701689ba07e23e48dbeec763dccf4cd7442418
add __shfl
cupy/cupy,cupy/cupy,cupy/cupy,cupy/cupy
cupy/_core/include/cupy/hip_workaround.cuh
cupy/_core/include/cupy/hip_workaround.cuh
#ifndef INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H #define INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H #ifdef __HIP_DEVICE_COMPILE__ // ignore mask #define __shfl_sync(m, x, y, z) __shfl(x, y, z) #define __shfl_up_sync(m, x, y, z) __shfl_up(x, y, z) #define __shfl_down_sync(m, x, y, z) __shfl_down(x, y, z) #define __shfl_xor_sync(m...
#ifndef INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H #define INCLUDE_GUARD_CUPY_HIP_WORKAROUND_H #ifdef __HIP_DEVICE_COMPILE__ // ignore mask #define __shfl_up_sync(m, x, y, z) __shfl_up(x, y, z) #define __shfl_down_sync(m, x, y, z) __shfl_down(x, y, z) #define __shfl_xor_sync(m, x, y, z) __shfl_xor(x, y, z) // It is guarant...
mit
Cuda
675c296c911c7281c0d66a36473691ec5f5bb688
Test is_partitioned with thrust::device in __device__ code.
jaredhoberock/thrust,GrimDerp/thrust,marksantos/thrust,egaburov/thrust,jaredhoberock/thrust,zhenglaizhang/thrust,jaredhoberock/thrust,arnabgho/thrust,mohamed-ali/thrust,thrust/thrust,xiongzhanblake/thrust,andrewcorrigan/thrust-multi-permutation-iterator,sdalton1/thrust,Ricardo666666/thrust,raygit/thrust,thrust/thrust,t...
testing/backend/cuda/is_partitioned.cu
testing/backend/cuda/is_partitioned.cu
#include <unittest/unittest.h> #include <thrust/partition.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename ExecutionPolicy, typename Iterator, typename Predicate, typename Iterator2> __global__ void is_partitioned_kernel(ExecutionPolicy exec, Iterator first, Iterator last, Pred...
#include <unittest/unittest.h> #include <thrust/partition.h> #include <thrust/functional.h> #include <thrust/execution_policy.h> template<typename Iterator, typename Predicate, typename Iterator2> __global__ void is_partitioned_kernel(Iterator first, Iterator last, Predicate pred, Iterator2 result) { *result = thru...
apache-2.0
Cuda
57d40b8005f88b3057d027df3b30cfef4472a21f
Make transpose_front faster
wichtounet/etl-gpu-blas,wichtounet/etl-gpu-blas
src/transpose_front.cu
src/transpose_front.cu
//======================================================================= // Copyright (c) 2017 Baptiste Wicht // Distributed under the terms of the MIT License. // (See accompanying file LICENSE or copy at // http://opensource.org/licenses/MIT) //=======================================================================...
//======================================================================= // Copyright (c) 2017 Baptiste Wicht // Distributed under the terms of the MIT License. // (See accompanying file LICENSE or copy at // http://opensource.org/licenses/MIT) //=======================================================================...
mit
Cuda
789525fd0b2f0b9a25b55faeec10548b8c524940
check cuda error
bvanderhaar/cuda-musclework,bvanderhaar/cuda-musclework,bvanderhaar/cuda-musclework
main.cu
main.cu
#include <stdio.h> #include <stdlib.h> /* * In CUDA it is necessary to define block sizes * The grid of data that will be worked on is divided into blocks */ #define BLOCK_SIZE 32 __global__ void cu_dotProduct(long long *distance_array_d, long long *force_array_d, ...
#include <stdio.h> #include <stdlib.h> /* * In CUDA it is necessary to define block sizes * The grid of data that will be worked on is divided into blocks */ #define BLOCK_SIZE 32 __global__ void cu_dotProduct(long long *distance_array_d, long long *force_array_d, long long *result_ar...
mit
Cuda
3bfe495dc34c1245930f7f589db82a7855f5c9bf
Bump version to 1.9.10. Commits prior to this are in CUB 1.9.9.
NVlabs/cub,NVlabs/CUB,NVIDIA/cub
cub/version.cuh
cub/version.cuh
/****************************************************************************** * Copyright (c) 2011-2020, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions are met: * * Redistrib...
/****************************************************************************** * Copyright (c) 2011-2020, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions are met: * * Redistri...
bsd-3-clause
Cuda
29fb88e9614cba72537db2d6813fa9707fd2e178
Fix test names.
quantumlib/qsim,quantumlib/qsim,quantumlib/qsim,quantumlib/qsim
tests/hybrid_cuda_test.cu
tests/hybrid_cuda_test.cu
// Copyright 2019 Google LLC. All Rights Reserved. // // Licensed under the Apache License, Version 2.0 (the "License"); // you may not use this file except in compliance with the License. // You may obtain a copy of the License at // // https://www.apache.org/licenses/LICENSE-2.0 // // Unless required by applicabl...
// Copyright 2019 Google LLC. All Rights Reserved. // // Licensed under the Apache License, Version 2.0 (the "License"); // you may not use this file except in compliance with the License. // You may obtain a copy of the License at // // https://www.apache.org/licenses/LICENSE-2.0 // // Unless required by applicabl...
apache-2.0
Cuda
b159a36e3f8598e9b161554f58ea5243cf8610ba
fix redundant macro in hl_device_functions.cuh
QiJune/Paddle,zuowang/Paddle,lispc/Paddle,dayhaha/Paddle,pengli09/Paddle,pkuyym/Paddle,zhouxiao-coder/Paddle,wen-bo-yang/Paddle,jacquesqiao/Paddle,zuowang/Paddle,luotao1/Paddle,livc/Paddle,chengduoZH/Paddle,yu239/Paddle,livc/Paddle,tensor-tang/Paddle,lcy-seso/Paddle,pengli09/Paddle,pkuyym/Paddle,Canpio/Paddle,putcn/Pad...
paddle/cuda/include/hl_device_functions.cuh
paddle/cuda/include/hl_device_functions.cuh
/* Copyright (c) 2016 Baidu, Inc. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to ...
/* Copyright (c) 2016 Baidu, Inc. All Rights Reserve. Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to ...
apache-2.0
Cuda
7abf1db66edd423c3439513bc13d269aab22ef53
Test shared memory default in SM 75 launch params
gunrock/gunrock,gunrock/gunrock,gunrock/gunrock
unittests/launch_box/test_launch_box.cu
unittests/launch_box/test_launch_box.cu
#include <iostream> #include <gunrock/cuda/launch_box.hxx> using namespace gunrock::cuda; int main(void) { // First template argument signifies the SM version typedef launch_box_t< sm_launch_params_t<86, 16, 64, 2>, sm_launch_params_t<80, 16, 32, 4>, sm_launch_params_t<75, 32, 64>, sm_launch_par...
#include <iostream> #include <gunrock/cuda/launch_box.hxx> using namespace gunrock::cuda; int main(void) { // First template argument signifies the SM version typedef launch_box_t< sm_launch_params_t<86, 16, 64, 2>, sm_launch_params_t<80, 16, 32, 4>, sm_launch_params_t<75, 32, 64, 8>, sm_launch_...
apache-2.0
Cuda
fcb59f935247469a3623dc21c519ed574a8a5a85
test all operators except dot. Probably a transpose needed
marian-nmt/marian-train,marian-nmt/marian-train,DianaDespa/marian-train,emjotde/Marian,DianaDespa/marian-train,emjotde/amunmt,emjotde/Marian,emjotde/amunmt,emjotde/amunn,emjotde/amunn,DianaDespa/marian-train,emjotde/amunn,afaji/Marian,afaji/Marian,amunmt/marian,afaji/Marian,afaji/Marian,amunmt/marian,DianaDespa/marian-...
src/test_nodes.cu
src/test_nodes.cu
#include <vector> #include <random> #include "marian.h" #include "expression_graph.h" #include "keywords.h" #include "definitions.h" float Rand() { float LO = -10; float HI = +20; float r3 = LO + static_cast <float> (rand()) /( static_cast <float> (RAND_MAX/(HI-LO))); return r3; } int main(int argc, char** argv)...
#include <vector> #include <random> #include "marian.h" #include "expression_graph.h" #include "keywords.h" #include "definitions.h" float Rand() { float LO = -10; float HI = +20; float r3 = LO + static_cast <float> (rand()) /( static_cast <float> (RAND_MAX/(HI-LO))); return r3; } int main(int argc, char** argv)...
mit
Cuda
c1bcd76ddc381b09175090c02a96a6b97f8b9f62
Fix bug in hash embed, where some values didn't get hash
explosion/thinc,explosion/thinc,spacy-io/thinc,spacy-io/thinc,explosion/thinc,spacy-io/thinc,explosion/thinc
include/_cuda_shim.cu
include/_cuda_shim.cu
#include <_kernels.cu> #include <_murmur3.cu> void gpu_maxout(float* best, int* which, const float* cands, int B, int O, int P) { maxout<<<B/16,16>>>(best, which, cands, B, O, P); } void gpu_mean_pool(float* means, const float* X, const int* lengths, int B, int T, int O) { mean_pool<<<B, 1>>>(mean...
#include <_kernels.cu> #include <_murmur3.cu> void gpu_maxout(float* best, int* which, const float* cands, int B, int O, int P) { maxout<<<B/16,16>>>(best, which, cands, B, O, P); } void gpu_mean_pool(float* means, const float* X, const int* lengths, int B, int T, int O) { mean_pool<<<B, 1>>>(mean...
mit
Cuda
8cad5b27318c85ab8abb7177d05b975ea5631015
Implement several optimizations to ICM
evilncrazy/GridInfCuda,evilncrazy/GridInfCuda
src/gpu/icm.cu
src/gpu/icm.cu
#include "../include/icm.h" #include "../include/potentials.h" #include <cuda.h> #include <cuda_runtime.h> #include <cstdio> namespace ginf { template <typename T> __device__ T gpuIcmGetLabelingCost(GpuGrid<T> *grid, PairwisePot<T> pot, int4 labeling, int label) { GINF_DECL_X; GINF_DECL_Y; return grid->getD...
#include "../include/icm.h" #include <cuda.h> #include <cuda_runtime.h> #include <cstdio> namespace ginf { template <typename T> __global__ void gpuIcmDecodeKernel(GpuGrid<T> *grid, int *result, int *old) { GINF_DECL_X; GINF_DECL_Y; MatDim dim(grid->getWidth(), grid->getHeight()); if (dim.isValid(x, y)) { ...
mit
Cuda
66f8100b068bb2dc1a63f23c6b917b4cc19d46f7
move kernel call to .cu file
cholla-hydro/cholla,evaneschneider/cholla,evaneschneider/cholla,cholla-hydro/cholla,evaneschneider/cholla,evaneschneider/cholla,cholla-hydro/cholla,cholla-hydro/cholla
src/cuda_pack_buffers.cu
src/cuda_pack_buffers.cu
#include"gpu.hpp" #include"global.h" #include"global_cuda.h" void PackBuffers3D(Real * buffer, Real * c_head, int isize, int jsize, int ksize, int nx, int ny, int idxoffset, int offset, int n_fields, int n_cells){ dim3 dim1dGrid((isize*jsize*ksize+TPB-1)/TPB, 1, 1); dim3 dim1dBlock(TPB, 1, 1); hipLaunchKernelG...
#include"gpu.hpp" #include"global.h" #include"global_cuda.h" void PackBuffers3D(Real * buffer, Real * c_head, int isize, int jsize, int ksize, int nx, int ny, int idxoffset, int offset, int n_fields, int n_cells){ dim3 dim1dGrid((isize*jsize*ksize+TPB-1)/TPB, 1, 1); dim3 dim1dBlock(TPB, 1, 1); hipLaunchKernelG...
mit
Cuda
b422bda1f367fbacdf685dff076283084b700e1c
debug error
buttonzzj/cuda_trial,buttonzzj/cuda_trial
mat_transpose.cu
mat_transpose.cu
#include <stdio.h> #include "timer.h" #include "utils.h" const int N = 1024; // we are transposing a N by N mat const int K = 1; void fill_matrix(float* mat){ for (int i = 0; i < N*N; i++){ mat[i] = (float)j; } } int main(int argc, char const *argv[]) { size_t mat_size = N * N * sizeof(float); ...
#include <stdio.h> #include "timer.h" #include "utils.h" const int N = 1024; // we are transposing a N by N mat const int K = 1; void fill_matrix(float* mat){ for (int i = 0; i < N*N; i++){ mat[i] = (float)j; } } int int main(int argc, char const *argv[]) { size_t mat_size = N * N * sizeof(float...
mit
Cuda
fcae3430808576c6a143562410f2527cc793bc70
fix take_along_axis cuda op register bug (#40270)
PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,PaddlePaddle/Paddle,luotao1/Paddle,luotao1/Paddle,luotao1/Paddle
paddle/phi/kernels/gpu/take_along_axis_kernel.cu
paddle/phi/kernels/gpu/take_along_axis_kernel.cu
// Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved. // // Licensed under the Apache License, Version 2.0 (the "License"); // you may not use this file except in compliance with the License. // You may obtain a copy of the License at // // http://www.apache.org/licenses/LICENSE-2.0 // // Unless required...
// Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved. // // Licensed under the Apache License, Version 2.0 (the "License"); // you may not use this file except in compliance with the License. // You may obtain a copy of the License at // // http://www.apache.org/licenses/LICENSE-2.0 // // Unless required...
apache-2.0
Cuda
e2ce20f7bbd6cfd2e7318dbda28174883e066610
Fix typo in sorting_aos_vs_soa.cu
GrimDerp/thrust,xiongzhanblake/thrust,jaredhoberock/thrust,xiongzhanblake/thrust_src,andrewcorrigan/thrust-multi-permutation-iterator,mohamed-ali/thrust,jaredhoberock/thrust,thrust/thrust,sdalton1/thrust,marksantos/thrust,thrust/thrust,marksantos/thrust,zhenglaizhang/thrust,arnabgho/thrust,thvasilo/thrust,arnabgho/thru...
examples/sorting_aos_vs_soa.cu
examples/sorting_aos_vs_soa.cu
#include <thrust/device_vector.h> #include <thrust/sort.h> #include <thrust/random.h> #include <assert.h> #include "include/timer.h" // This examples compares sorting performance using Array of Structures (AoS) // and Structure of Arrays (SoA) data layout. Legacy applications will often // store data in C/C++ struct...
#include <thrust/device_vector.h> #include <thrust/sort.h> #include <thrust/random.h> #include <assert.h> #include "include/timer.h" // This examples compares sorting performance using Array of Structures (AoS) // and Structure of Arrays (SoA) data layout. Legacy applications will often // store data in C/C++ struct...
apache-2.0
Cuda
174ba2fe2799d35ea2f2c49046555278d5770608
Fix all the typecasting
TAdeJong/plasma-analysis,TAdeJong/plasma-analysis
code/RK4.cu
code/RK4.cu
#include <stdio.h> texture <float4, cudaTextureType3D, cudaReadModeElementType> dataTex; int N = 256; //Definitions of vectortype operators __device__ float3 operator+(const float3 &a, const float3 &b) { return make_float3(a.x+b.x, a.y+b.y, a.z+b.z); } __device__ float3 operator*(const float &a, const float3 &b) { ...
#include <stdio.h> texture <float4, cudaTextureType3D> dataTex; int N = 256; //Definitions of vectortype operators __device__ float3 operator+(const float3 &a, const float3 &b) { return make_float3(a.x+b.x, a.y+b.y, a.z+b.z); } __device__ float3 operator*(const float &a, const float3 &b) { return make_float3(a*b.x,...
mit
Cuda
fdf151d66b60adbc0f0c3ae2023dbb29a497f261
Test minmax_element with thrust::device in __device__ code.
sdalton1/thrust,zeryx/thrust,Ricardo666666/thrust,thrust/thrust,thrust/thrust,arnabgho/thrust,sdalton1/thrust,thrust/thrust,dachziegel/thrust,andrewcorrigan/thrust-multi-permutation-iterator,GrimDerp/thrust,jaredhoberock/thrust,xiongzhanblake/thrust,zhenglaizhang/thrust,dachziegel/thrust,Ricardo666666/thrust,arnabgho/t...
testing/backend/cuda/minmax_element.cu
testing/backend/cuda/minmax_element.cu
#include <unittest/unittest.h> #include <thrust/extrema.h> template<typename ExecutionPolicy, typename Iterator1, typename Iterator2> __global__ void minmax_element_kernel(ExecutionPolicy exec, Iterator1 first, Iterator1 last, Iterator2 result) { *result = thrust::minmax_element(exec, first, last); } template<typ...
#include <unittest/unittest.h> #include <thrust/extrema.h> template<typename Iterator1, typename Iterator2> __global__ void minmax_element_kernel(Iterator1 first, Iterator1 last, Iterator2 result) { *result = thrust::minmax_element(thrust::seq, first, last); } template<typename Iterator1, typename Iterator2, type...
apache-2.0
Cuda
d292493311baeae473eb40a6cc9226b59699da00
add restrict
MeteoSwiss-APN/comm_overlap_bench,MeteoSwiss-APN/comm_overlap_bench
src/Kernel.cu
src/Kernel.cu
#include "Kernel.h" __global__ void cukernel(Real __restrict__ * in, Real __restrict__* out, const int kSize, const int iStride, const int jStride, const int kStride) { int ipos = blockIdx.x * 32 + threadIdx.x; int jpos = blockIdx.y * 8 + threadIdx.y; out[ipos*iStride + jpos*jStride] = (pow(in[ipos*iStr...
#include "Kernel.h" __global__ void cukernel(Real* in, Real* out, const int kSize, const int iStride, const int jStride, const int kStride) { int ipos = blockIdx.x * 32 + threadIdx.x; int jpos = blockIdx.y * 8 + threadIdx.y; out[ipos*iStride + jpos*jStride] = (pow(in[ipos*iStride + jpos*jStride] *in[ipo...
bsd-2-clause
Cuda
5b8ebb63e9688cf224757a07317d5463988c2c1e
clean m_utils.cu
gkc1000/pyscf,sunqm/pyscf,gkc1000/pyscf,sunqm/pyscf,gkc1000/pyscf,gkc1000/pyscf,gkc1000/pyscf,sunqm/pyscf,sunqm/pyscf
pyscf/lib/nao/nao_gpu/m_utils.cu
pyscf/lib/nao/nao_gpu/m_utils.cu
/* simple wrapper to utility cuda routines */ #include <stdlib.h> #include <stdio.h> #include <cuda.h> #include <cuda_runtime.h> extern "C" int CountDevices() { int num_gpus = -1; cudaGetDeviceCount(&num_gpus); return num_gpus; } extern "C" void SetDevice(int gpu_id) { cudaSetDevice(gpu_id); } extern ...
/* simple wrapper to utility cuda routines */ #include <stdlib.h> #include <stdio.h> #include <cuda.h> #include <cuda_runtime.h> #include <helper_functions.h> #include <helper_cuda.h> extern "C" int CountDevices() { int num_gpus = -1; checkCudaErrors(cudaGetDeviceCount(&num_gpus)); return num_gpus; } ex...
apache-2.0
Cuda
cee18186e16120b03514640d16fb4840b10c9e7d
Remove unused code.
nakdai/aten,nakdai/aten
src/libidaten/kernel/bvh.cuh
src/libidaten/kernel/bvh.cuh
#pragma once #include "aten4idaten.h" #include "kernel/context.cuh" #include "kernel/intersect.cuh" #include <cuda_runtime.h> #include <device_launch_parameters.h> #include "cuda/helper_math.h" __device__ bool intersectBVH( const Context* ctxt, const aten::ray& r, aten::Intersection* isect); __device__ bool in...
#pragma once #include "aten4idaten.h" #include "kernel/context.cuh" #include "kernel/intersect.cuh" #include <cuda_runtime.h> #include <device_launch_parameters.h> #include "cuda/helper_math.h" enum IntersectType { Closest, Closer, Any, }; __device__ bool intersectBVH( const Context* ctxt, const aten::ray& r...
mit
Cuda
6438ff4730c457e3356016c48af33fde4a1845a9
Add necessary undef for CUDA 11.5 CUB fix
NVIDIA/nvcomp,NVIDIA/nvcomp,NVIDIA/nvcomp
src/nvcomp_cub.cuh
src/nvcomp_cub.cuh
/* * Copyright (c) 2021, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions * are met: * * Redistributions of source code must retain the above copyright * notice, this list of co...
/* * Copyright (c) 2021, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions * are met: * * Redistributions of source code must retain the above copyright * notice, this list of co...
bsd-3-clause
Cuda
7b4a5eec16442850bbe58358bee9ff7c98de0a9e
update device
cosunae/dycore_stencils
horizontal_diffusion/horizontal_diffusion_benchmark.cu
horizontal_diffusion/horizontal_diffusion_benchmark.cu
#include "gtest/gtest.h" #include "../Options.hpp" #include "horizontal_diffusion.h" #include "../repository.hpp" #include "../verifier.hpp" #include "horizontal_diffusion_reference.hpp" int main(int argc, char** argv) { // Pass command line arguments to googltest ::testing::InitGoogleTest(&argc, argv); ...
#include "gtest/gtest.h" #include "../Options.hpp" #include "horizontal_diffusion.h" #include "../repository.hpp" #include "../verifier.hpp" #include "horizontal_diffusion_reference.hpp" int main(int argc, char** argv) { // Pass command line arguments to googltest ::testing::InitGoogleTest(&argc, argv); ...
bsd-3-clause
Cuda
bc9b4ea683ec8f9bea8562f5ed60fe8916ee4973
Fix #401 Improve CUDA Memory Manager functions
GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC,GOMC-WSU/GOMC
src/GPU/CUDAMemoryManager.cu
src/GPU/CUDAMemoryManager.cu
/******************************************************************************* GPU OPTIMIZED MONTE CARLO (GOMC) 2.70 Copyright (C) 2018 GOMC Group A copy of the GNU General Public License can be found in the COPYRIGHT.txt along with this program, also can be found at <http://www.gnu.org/licenses/>. *****************...
/******************************************************************************* GPU OPTIMIZED MONTE CARLO (GOMC) 2.70 Copyright (C) 2018 GOMC Group A copy of the GNU General Public License can be found in the COPYRIGHT.txt along with this program, also can be found at <http://www.gnu.org/licenses/>. *****************...
mit
Cuda
a6996ec8fb14de8550e8c41404429e19e27ac1f2
Update comments, minor fix
schatten/moment,schatten/moment,schatten/moment
test/neuron-test.cu
test/neuron-test.cu
/* Test neuron functionality */ #include <stdio.h> // Note that we are including the source file and not the header file only. // This allows us access to static variables and globals (gasp!). This is more // or less a close replica of the exposure that the functions being tested will // get. #include "neuron.cu" #in...
/* Test neuron functionality */ #include <stdio.h> // Note that we are including the source file and not the header file only. // This allows us access to static variables and globals (gasp!). This is more // or less a close replica of the exposure that the functions being tested will // get. #include "neuron.cu" #in...
mit
Cuda
ea9e6ef5576bea58115d7a7bb8cb243ce0d5bc82
resolve cuda warnings
JasonRuonanWang/ADIOS2,ornladios/ADIOS2,JasonRuonanWang/ADIOS2,ornladios/ADIOS2,JasonRuonanWang/ADIOS2,ornladios/ADIOS2,ornladios/ADIOS2,JasonRuonanWang/ADIOS2,ornladios/ADIOS2,JasonRuonanWang/ADIOS2
source/adios2/helper/adiosCUDA.cu
source/adios2/helper/adiosCUDA.cu
/* * Distributed under the OSI-approved Apache License, Version 2.0. See * accompanying file Copyright.txt for details. * * adiosCUDA.cpp * * Created on: May 9, 2021 * Author: Ana Gainaru gainarua@ornl.gov */ #ifndef ADIOS2_HELPER_ADIOSCUDA_CU_ #define ADIOS2_HELPER_ADIOSCUDA_CU_ #include <thrust/extre...
/* * Distributed under the OSI-approved Apache License, Version 2.0. See * accompanying file Copyright.txt for details. * * adiosCUDA.cpp * * Created on: May 9, 2021 * Author: Ana Gainaru gainarua@ornl.gov */ #ifndef ADIOS2_HELPER_ADIOSCUDA_CU_ #define ADIOS2_HELPER_ADIOSCUDA_CU_ #include <thrust/extre...
apache-2.0
Cuda
9c708f5c693e98ecdfe20341eb3efd263b10a1be
Bump version to 1.11.0.
NVIDIA/cub,NVlabs/cub,NVlabs/CUB
cub/version.cuh
cub/version.cuh
/****************************************************************************** * Copyright (c) 2011-2020, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions are met: * * Redistrib...
/****************************************************************************** * Copyright (c) 2011-2020, NVIDIA CORPORATION. All rights reserved. * * Redistribution and use in source and binary forms, with or without * modification, are permitted provided that the following conditions are met: * * Redistrib...
bsd-3-clause
Cuda
427348985e51d8ff911de5b9dbde47cab02129b0
Add device limits to cuda_device_info experiment
Trass3r/Halide,darkbuck/Halide,darkbuck/Halide,Trass3r/Halide,Trass3r/Halide,Trass3r/Halide,Trass3r/Halide,darkbuck/Halide,darkbuck/Halide,darkbuck/Halide,darkbuck/Halide,Trass3r/Halide,darkbuck/Halide,Trass3r/Halide
experiments/cuda_device_info.cu
experiments/cuda_device_info.cu
#include <stdio.h> // Print device properties void printDevProp(cudaDeviceProp devProp) { printf("Major revision number: %d\n", devProp.major); printf("Minor revision number: %d\n", devProp.minor); printf("Name: %s\n", devProp.name); printf("Total global memo...
#include <stdio.h> // Print device properties void printDevProp(cudaDeviceProp devProp) { printf("Major revision number: %d\n", devProp.major); printf("Minor revision number: %d\n", devProp.minor); printf("Name: %s\n", devProp.name); printf("Total global memo...
mit
Cuda
67d79d87d11db8847b35c1127a77ac80a207ea32
fix warning message
poparteu/CCTag,poparteu/CCTag,poparteu/CCTag,poparteu/CCTag
src/cuda/frame_01_tex.cu
src/cuda/frame_01_tex.cu
#include "frame.h" #include "debug_macros.hpp" #include <cuda_runtime.h> namespace popart { using namespace std; __global__ void cu_fill_from_texture( cv::cuda::PtrStepSzb dst, cudaTextureObject_t tex ) { uint32_t idy = blockIdx.y; uint32_t idx = blockIdx.x * 32 + threadIdx.x; if( idy >= dst.rows ) retu...
#include "frame.h" #include "debug_macros.hpp" #include <cuda_runtime.h> namespace popart { using namespace std; __global__ void cu_fill_from_texture( cv::cuda::PtrStepSzb dst, cudaTextureObject_t tex ) { uint32_t idy = blockIdx.y; uint32_t idx = blockIdx.x * 32 + threadIdx.x; if( idy >= dst.rows ) retu...
mpl-2.0
Cuda
2ab4646040df2ad1b77e625c00ca814520380bbd
Add -target to cuda-constructor-alias.cu test so it doesn't fail on Mac.
llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,llvm-mirror/clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-clang,llvm-mirror/clang,apple/swift-clang,apple/swift-cl...
test/Driver/cuda-constructor-alias.cu
test/Driver/cuda-constructor-alias.cu
// REQUIRES: clang-driver // REQUIRES: x86-registered-target // REQUIRES: nvptx-registered-target // Check that we don't pass -mconstructor-aliases to CUDA device-side // compilation, but we do pass it to host-side compilation. // RUN: %clang -### -target x86_64-linux-gnu %s 2>&1 | FileCheck %s // CHECK: "-cc1" // CH...
// REQUIRES: clang-driver // REQUIRES: x86-registered-target // REQUIRES: nvptx-registered-target // Check that we don't pass -mconstructor-aliases to CUDA device-side // compilation, but we do pass it to host-side compilation. // RUN: %clang -### %s 2>&1 | FileCheck %s // CHECK: "-cc1" // CHECK-NOT: "-fcuda-is-devic...
apache-2.0
Cuda
c08251e0d5cdb1d2227fe3dca9b64105b11eb0ba
use long long for all
bvanderhaar/cuda-musclework,bvanderhaar/cuda-musclework,bvanderhaar/cuda-musclework
main.cu
main.cu
#include <stdio.h> #include <stdlib.h> /* * In CUDA it is necessary to define block sizes * The grid of data that will be worked on is divided into blocks */ #define BLOCK_SIZE 32 __global__ void cu_dotProduct(long long *distance_array_d, long long *force_array_d, long long *result_ar...
#include <stdio.h> #include <stdlib.h> /* * In CUDA it is necessary to define block sizes * The grid of data that will be worked on is divided into blocks */ #define BLOCK_SIZE 32 __global__ void cu_dotProduct(int *distance_array_d, int *force_array_d, long long *result_array_d, int m...
mit
Cuda